#
# spec file for package open-iscsi
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _home_dir %{_sysconfdir}/iscsi

# Ensure usr-merge does not effect existing SLE. Cannot use _sbindir
# directly since meson macros pass that on, and meson does not like
# setting it to "/sbin".  Also move DB root to /var/lib/iscsi. For
# SLE, we can just ove lockdir to /run/lock/iscsi
%define _lockdir %{_rundir}/lock/iscsi
%if ! 0%{?is_opensuse}
# sle
%define _iscsi_sbindir /sbin
%if 0%{?suse_version} <= 1540
%define _dbroot %{_home_dir}
%else
%define _dbroot %{_sharedstatedir}/iscsi
%define _dbroot_new 1
%endif
%else
# opensuse
%define _iscsi_sbindir /usr/sbin
%define _dbroot %{_sharedstatedir}/iscsi
%define _dbroot_new 1
%endif
%if 0%{?_dbroot_new}
%define _install_dbdir_move_readme_value true
%else
%define _install_dbdir_move_readme_value false
%endif

%define iscsi_minor_release 1
%define iscsi_patch_release 11
%define iscsi_patch_release_suse %{iscsi_patch_release}.suse
%define iscsi_service_tag 65.65365e1cdedb
%define libname libopeniscsiusr0
%define libversion 0.2.0
Name:           open-iscsi
Version:        2.1.11
Release:        107.1
Summary:        Linux iSCSI Software Initiator
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Other
URL:            https://www.open-iscsi.com
Source:         %{name}-2.%{iscsi_minor_release}.%{iscsi_patch_release_suse}+%{iscsi_service_tag}.tar.xz
BuildRequires:  bison
BuildRequires:  db-devel < 5
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  libkmod-devel
BuildRequires:  libmount-devel
BuildRequires:  libtool
BuildRequires:  meson >= 0.54.0
BuildRequires:  open-isns-devel
BuildRequires:  openssl-devel >= 1.1.1c
BuildRequires:  perl
BuildRequires:  pkg-config
BuildRequires:  suse-module-tools
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(systemd)
Requires(post): coreutils
Requires:       %{libname} = %{libversion}
%{?systemd_requires}

%description
This is a transport independent implementation of RFC 3720
iSCSI. It is partitioned into user and kernel parts.

The kernel portion of Open-iSCSI implements the iSCSI data path (that
is, iSCSI Read and iSCSI Write), and consists of two loadable
modules: iscsi_if.ko and iscsi_tcp.ko, and is now is delivered
as part of the kernel.

The user-space part contains the entire control plane: configuration
manager, iSCSI Discovery, Login and Logout processing,
connection-level error processing, Nop-In and Nop-Out handling. It
comes with a daemon process called iscsid, and a management utility,
iscsiadm.

%package -n %{libname}
Version:        0.2.0
Release:        107.1
Summary:        The iSCSI User-level Library
Group:          System/Libraries
Obsoletes:      libopeniscsiusr0_1_0 <= 2.1.7
Obsoletes:      libopeniscsiusr0_2_0 <= 2.1.7

%description -n %{libname}
The iSCSI user-space API from the open-iscsi project.

%package -n iscsiuio
Version:        0.7.8.8
Release:        107.1
Summary:        Linux Broadcom NetXtremem II iscsi server
Group:          Productivity/Networking/Other
Requires:       logrotate

%description -n iscsiuio
This tool is to be used in conjunction with the Broadcom NetXtreme II Linux
driver (Kernel module name: "bnx2" and "bnx2x"), Broadcom CNIC driver,
and the Broadcom iSCSI driver (Kernel module name: "bnx2i").
This user-space tool is used in conjunction with the following
Broadcom Network Controllers:

* bnx2:  BCM5706, BCM5708, BCM5709 devices
* bnx2x: BCM57710, BCM57711, BCM57711E, BCM57712, BCM57712E,
         BCM57800, BCM57810, BCM57840 devices

This utility will provide the ARP and DHCP functionality for the iSCSI offload.
The communication to the driver is done via user-space I/O (Kernel module name
"uio").

%package devel
Version:        2.%{iscsi_minor_release}.%{iscsi_patch_release}
Release:        107.1
Summary:        The iSCSI User-level Library Development Library and Include files
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{libversion}
Requires:       %{name} = %{version}
Conflicts:      libopeniscsiusr0_1_0
Conflicts:      libopeniscsiusr0_2_0

%description devel
This development package contains the open-iscsi user-level library
include files and documentation. These are used to compile against
the libopeniscsiusr library.

%prep
%setup -q -n %{name}-2.%{iscsi_minor_release}.%{iscsi_patch_release_suse}+%{iscsi_service_tag}

%build
[ -z "$SOURCE_DATE_EPOCH" ] || export KBUILD_BUILD_TIMESTAMP=@$SOURCE_DATE_EPOCH
%meson --libdir=%{_libdir} \
	-Dc_args="%{optflags} -fno-strict-aliasing -fno-common -DOFFLOAD_BOOT_SUPPORTED" \
	-Discsi_sbindir=%{_iscsi_sbindir} -Ddbroot=%{_dbroot} -Drulesdir=%{_udevrulesdir} -Dlockdir=%{_lockdir} \
	-Dinstall_dbdir_move_readme=%{_install_dbdir_move_readme_value}
%meson_build

%install
%meson_install
[ -d %{buildroot}%{_iscsi_sbindir} ] || mkdir -p %{buildroot}%{_iscsi_sbindir}
# create brcm_iscsiuio symlink if needed
[ -e %{buildroot}%{_iscsi_sbindir}/brcm_iscsiuio ] || \
    ln -s %{_iscsi_sbindir}/iscsiuio %{buildroot}%{_iscsi_sbindir}/brcm_iscsiuio
%if 0%{?suse_version} < 1600
# create rc symlinks
ln -s %{_iscsi_sbindir}/service %{buildroot}%{_iscsi_sbindir}/rciscsi
ln -s %{_iscsi_sbindir}/service %{buildroot}%{_iscsi_sbindir}/rciscsid
ln -s %{_iscsi_sbindir}/service %{buildroot}%{_iscsi_sbindir}/rciscsiuio
ln -s %{_iscsi_sbindir}/service %{buildroot}%{_iscsi_sbindir}/rciscsi-init
%endif
(cd %{buildroot}/etc; ln -sf iscsi/iscsid.conf iscsid.conf)
# create an empty initiatorname file, as a package place holder
echo > %{buildroot}%{_home_dir}/initiatorname.iscsi
# rename iscsiuio logrotate file to proper name
%if 0%{?suse_version} > 1500
mkdir -p %{buildroot}%{_distconfdir}/logrotate.d
mv %{buildroot}%{_sysconfdir}/logrotate.d/iscsiuiolog %{buildroot}%{_distconfdir}/logrotate.d/iscsiuio
%else
mv %{buildroot}%{_sysconfdir}/logrotate.d/iscsiuiolog %{buildroot}%{_sysconfdir}/logrotate.d/iscsiuio
%endif
%fdupes %{buildroot}/%{_prefix}

%pre
%service_add_pre iscsi.service iscsid.service iscsid.socket iscsi-init.service

%post
%{?regenerate_initrd_post}
if [ ! -f %{_home_dir}/initiatorname.iscsi ] ; then
    %{_iscsi_sbindir}/iscsi-gen-initiatorname
fi
%if 0%{?_dbroot_new}
# move DB files if and only if not present in new location
for d in ifaces send_targets fw nodes static isns slp; do
    if [ -d %{_home_dir}/$d ]; then
	if [ -d %{_dbroot}/$d ]; then
	    echo "Warning: cannot copy DB directory %{_home_dir}/$d to %{_dbroot}/$d: already present" 1>&2
	else
	    cp -a %{_home_dir}/$d %{_dbroot}
	fi
    fi
done
%endif
%service_add_post iscsi.service iscsid.service iscsid.socket iscsi-init.service

%posttrans
%{?regenerate_initrd_posttrans}

%preun
%service_del_preun iscsi.service iscsid.service iscsid.socket iscsi-init.service

%postun
%service_del_postun_without_restart iscsi.service
%service_del_postun iscsi.service iscsid.service iscsid.socket iscsi-init.service

%post   -n %{libname} -p %{run_ldconfig}
%postun -n %{libname} -p %{run_ldconfig}

%post -n iscsiuio
%service_add_post iscsiuio.service iscsiuio.socket

%postun -n iscsiuio
%service_del_postun iscsiuio.service iscsiuio.socket

%pre -n iscsiuio
%service_add_pre iscsiuio.service iscsiuio.socket

%preun -n iscsiuio
%service_del_preun iscsiuio.service iscsiuio.socket

%files
%dir %{_home_dir}
%{_sysconfdir}/iscsid.conf
%attr(0600,root,root) %config(noreplace) %{_home_dir}/iscsid.conf
%ghost %{_home_dir}/initiatorname.iscsi
%if 0%{?_dbroot_new}
%config %{_home_dir}/README.DB-files-moved
%endif
%dir %{_dbroot}
%dir %{_dbroot}/ifaces
%{_dbroot}/ifaces/iface.example
%attr(0644,root,root) %{_unitdir}/iscsid.service
%attr(0644,root,root) %{_unitdir}/iscsid.socket
%attr(0644,root,root) %{_unitdir}/iscsi-init.service
%attr(0644,root,root) %{_unitdir}/iscsi.service
%{_systemdgeneratordir}/ibft-rule-generator
%if 0%{?suse_version} < 1600
%{_iscsi_sbindir}/rciscsi
%{_iscsi_sbindir}/rciscsid
%{_iscsi_sbindir}/rciscsi-init
%endif
%{_iscsi_sbindir}/iscsid
%{_iscsi_sbindir}/iscsiadm
%{_iscsi_sbindir}/iscsi-iname
%{_iscsi_sbindir}/iscsistart
%{_iscsi_sbindir}/iscsi-gen-initiatorname
%{_iscsi_sbindir}/iscsi_offload
%{_iscsi_sbindir}/iscsi_discovery
%{_iscsi_sbindir}/iscsi_fw_login
%doc README
%license COPYING
%{_mandir}/man8/iscsiadm.8%{ext_man}
%{_mandir}/man8/iscsid.8%{ext_man}
%{_mandir}/man8/iscsi_discovery.8%{ext_man}
%{_mandir}/man8/iscsistart.8%{ext_man}
%{_mandir}/man8/iscsi-iname.8%{ext_man}
%{_mandir}/man8/iscsi_fw_login.8%{ext_man}
%{_mandir}/man8/iscsi-gen-initiatorname.8%{ext_man}
%{_udevrulesdir}/50-iscsi-firmware-login.rules

%files -n %{libname}
%{_libdir}/libopeniscsiusr.so.*

%files -n iscsiuio
%{_iscsi_sbindir}/iscsiuio
%{_iscsi_sbindir}/brcm_iscsiuio
%{_mandir}/man8/iscsiuio.8%{ext_man}
%if 0%{?suse_version} > 1500
%dir %{_distconfdir}/logrotate.d
%{_distconfdir}/logrotate.d/iscsiuio
%else
%config %{_sysconfdir}/logrotate.d/iscsiuio
%endif
%attr(0644,root,root) %{_unitdir}/iscsiuio.service
%attr(0644,root,root) %{_unitdir}/iscsiuio.socket
%if 0%{?suse_version} < 1600
%{_iscsi_sbindir}/rciscsiuio
%endif

%files devel
%{_includedir}/libopeniscsiusr*.h
%{_mandir}/man3/*.3%{ext_man}
%{_libdir}/libopeniscsiusr.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Mon Apr  7 2025 Lee Duncan <lduncan@suse.com>
- Change SPEC file so that open-iscsi lock files always go
  in /run/lock/iscsi (bsc#1239107)
* Mon Apr  7 2025 lduncan@suse.com
- Update to version 2.1.11.suse+65.65365e1cdedb:
  * doc: fixup iscsiadm man page option for -r (#501)
  * Modify log function to print session id (#498)
  * Fix minor typo ("authenticaton") (#500)
  * Preparing for version 2.1.11 (#499)
  * iscsid: Rate limit session reopen log messages (#492)
  * IPv6 support for iBFT iSCSI boot (#493)
  * Improve iscsiadm command line parsing messages (#494)
  * More testing cleanup, and fix dprint test usage (#491)
  * Fix a typo in test/README (#486)
  * iscsid: Fix hang during login with scan=manual (#485)
  * fix 4 issues which are finded when building with clang 17 (#478)
* Wed Jan 22 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Drop rcFOO symlinks for CODE16 (PED-266).
* Mon Sep 30 2024 lduncan@suse.com
- Update to version 2.1.10.suse+51.fea0fde82ed1:
  * Incudes upstream version 2.1.10 plus some fixes
  * Fix firmware targets startup to always be "onboot" (#482)
    (bsc#1228084)
  * Change a discovery function to void return type (#481)
  * Fix gcc issues (#480)
  * Bugfix read specific sysfs value "off" of session attribute (#466)
  * Fix bug where abort_tmo read failures were ignored. (#467)
  * grammar nitpicks (#464)
  * Fix memory leak in iscsi_check_session_use_count (#465)
  * improve the comments in idbm_lock() (#458)
  * Make it visible when memory allocation failure (#457)
  * Better handle multiple iscsiadm commands (#453)
  * iscsiadm: allow hostnames in node-mode commands (#451)
  * Modify how workqueue priority is set (#445)
  * Fix authmethod check by printing a warning message when CHAP used and authmethod=None (#443)
  * iscsid: Rescan devices on relogin (#444)
  * Adds missing characters in README. (#440)
  * Turn off iSCSI NOP-Outs, by default.
  * fix: add usr/iscsid_req.h missinig underline (#431) (#436)
* Wed Dec 20 2023 Lee Duncan <lduncan@suse.com>
- Updated to latest upstream: two small changes, with no known
  functional changes:
  * Incorrect documentation for `iscsiadm -m session` print level
    (upstream issue #432)
  * Stop using deprecated inet_aton and inet_ntoa (upstream issue
    [#435])
- Also, stopped using pre-prepared tarballs for the build, instead
  now using a service file to get latest SUSE srouces directly.
  This removed these two files:
  * open-iscsi-2.1.9-suse.tar.bz2, and
  * open-iscsi-SUSE-latest.diff.bz2
  whcih were both created by a shell script, and added a service-
  file-generated file of the form:
  * open-iscsi-2.1.9.suse+TAG_OFFSET.tar.xz
  where TAG_OFFSET is of the form "COMMIT_COUNT.HASH", where
  COMMIT_COUNT is the count of commits since 2.1.9-suse (in this
  case), and HASH is the git commit hash being used.
* Wed Oct 25 2023 Lee Duncan <lduncan@suse.com>
- Updated to latest upstream, which includes (bsc#1210514):
  * several fixes to harden iscsiuio, including:
  - logging now uses syslog
  - shutdown now waits for helper threads to complete
  - netlink socket cleanup
  * some minor bug fixes, some helping builds on musl
  This updates iscsiuio version to 0.7.8.8.
  This updates open-iscsi-SUSE-latest.diff.bz2
* Tue Jun 20 2023 Lee Duncan <lduncan@suse.com>
- Fix iscsiuio build version by updating iscsiuio/meson.build
  and RPM SPEC file (bsc#1210514), updating
  open-iscsi-SUSE-latest.diff.bz2
* Thu Jun 15 2023 Lee Duncan <lduncan@suse.com>
- Upgrade to upstream version 2.1.9 with tag "2.1.9-suse"
  (bsc#1210514), replacing open-iscsi-2.1.8-suse.tar.bz2 with
  open-iscsi-2.1.9-suse.tar.bz2, and resetting
  open-iscsi-SUSE-latest.diff.bz2. A summary from the ChangeLog
  file:
  * Fix discoveryd compiler warning
  * Sync iscsi_if.h with kernel
  * Handle old DB records correctly
  * Make IQN configuration for iscsi-iname
  * remove OFFLOAD_BOOT_SUPPORTED, which is always true
  * Use UUID for IPC, not "root"
  * do not support SHA3 for libressl
  * build meson cleanups, including changing default DB home
  * Updated README about NOPs
  * Remove "BindTo" in systemd service file
  * Some iscsiuio fixes, including licensing and memory leaks
    (bsc#1210514)
  * Small netlink fixes
  * Fix OOM adjustment
  * Some error recovery fixes
  * Some spelling fixes
* Mon Apr 17 2023 Lee Duncan <lduncan@suse.com>
- Remove "--strip" in SPEC file for meson build, so that
  debuginfo is generated. (from mwilck) (bsc#1210536)
* Sat Feb 25 2023 Lee Duncan <lduncan@suse.com>
- Build system: meson builds were ignoring optflags, and other
  passed in compiler options.
* Wed Dec 21 2022 Lee Duncan <lduncan@suse.com>
- Update iscsid.service so it starts iscsid.socket, if needed
  (bsc#1206132).
* Mon Dec 19 2022 Lee Duncan <lduncan@suse.com>
- Updated SPEC file dependencies for libopeniscsiusr to avoid
  conflicting package installation.
* Wed Dec  7 2022 Lee Duncan <lduncan@suse.com>
- Moving DB files from /etc/iscsi/* to /var/lib/iscsi/* for
  SLE-15-SP5 and forward, as is done in Tumbleweed.
- Added /etc/iscsi/README.DB-files-moved, and added SPEC file
  changes to support this, including a post-install script to
  move the DB files, only installed if DB files are moved.
- Renamed shared library from libopeniscsiusr0_2_0 to
  libopeniscsiusr0, to correctly match SONAME in library.
* Wed Nov 16 2022 Lee Duncan <lduncan@suse.com>
- Updated to latest upstream. Changes:
  * iscsid/iscsiuio: fix OOM adjustment (github issue #377)
* Mon Sep 26 2022 Lee Duncan <lduncan@suse.com>
- Update to upstream version 2.1.8, which includes some bug fixes,
  and adds the ability to build using meson. The SPEC file was
  updated to use meson.
  Also, some files have moved:
  * the "lock" file has moved from /etc/iscsi to /var/lock/iscsi
  * the "database files" have moved from /etc/iscsi to
    /var/lib/iscsi
* Wed Jul  6 2022 Lee Duncan <lduncan@suse.com>
- Modify SPEC file so systemd unit files are mode 644 (not 755)
  (bsc#1200570)
* Fri Jun 17 2022 Lee Duncan <lduncan@suse.com>
- For Tumbleweed, moved logrotate files from user-specific
  directory /etc/logrotate.d to vendor-specific
  /usr/etc/logrotate.d
  (for Stefan Schubert <schubi@suse.com>)
* Fri May 13 2022 Lee Duncan <lduncan@suse.com>
- Set initiatorname in %%post (at end of install), for cases
  where root is read-only at startup time (bsc#1198457)
* Mon May  9 2022 Lee Duncan <lduncan@suse.com>
- Update to latest upstream, including:
  * Added 'distclean' to Makefile targets
  * Ensure Makefile '.PHONY' targets set up correctly
  * fix an iscsid logout bug generating a false error
    and cleanup logout error messages
* Fri May  6 2022 Lee Duncan <lduncan@suse.com>
- Updated to latest upstream version, tagged 2.1.7. Changes
  included:
  * updated/fixed test script
  * updated build system
  * several bug fixes, including one for bsc#1199264
* Wed Apr  6 2022 Lee Duncan <lduncan@suse.com>
- Updated to latest upstream, including bug fixes and cleanups.
  Changes included:
  * add handling name/value pairs for firmware login (bsc#1196113),
    including man page update for same
  * Fix bug where some package parts were installed using
    DESTDIR twice
  * general build cleanup (in prep for removing DB files from
    /etc/iscsi some day soon)
  Also, now delivering a "package config" file for libopeniscsiusr.
* Sat Mar  5 2022 Lee Duncan <lduncan@suse.com>
- Update to latest upstream, including test cleanup, minor
  bug fixes (cosmetic), and fixing iscsi-init (bsc#1195656).
* Mon Feb 14 2022 Lee Duncan <lduncan@suse.com>
- Updated to latest upstream 2.1.6 as 2.1.6-suse, which contains
  bug fixes and cleanups. See the Changelog for more details.
* Thu Nov 11 2021 Lee Duncan <lduncan@suse.com>
- Merged latest upstream. Mostly cleanup, but includes a fix for
  iscsi-init.service when trying to write to the root volume too
  early (bsc#1192568), as well as an upstream fix for possible
  deadlock when dealing with sysfs.
* Mon Oct 25 2021 Lee Duncan <lduncan@suse.com>
- Fix the usr-merge changes (bsc#1192013). This includes catching
  all the places that /sbin was still used directly, as well as
  making the SPEC file build using /usr/sbin for openSUSE but
  still use /sbin for SLE, for now.
* Tue Oct  5 2021 Lee Duncan <lduncan@suse.com>
- Fix possible systemd cycle by adding an "obsoletes" for
  the old libopeniscsiusr for older versions.
* Thu Sep 30 2021 Lee Duncan <lduncan@suse.com>
- Update to latest from upstream, fixing:
  * Moving the executables from /sbin to /usr/sbin (bsc#1191054)
  * Remove default dependencies from iscsi-init.service
  (bsc#1187190)
* Wed Sep  8 2021 Lee Duncan <lduncan@suse.com>
- Updated to latest upstream 2.1.5 as 2.1.5-suse, which contains
  these changes not already present:
  * Handle IPv6 interfaces correctly. (bsc#1187958)
  * Handle qedi correctly in NPAR mode (bsc#1187958)
  * Update iscsiadm man page (bsc#1187958)
  * Update iface.example for ipv6
  * Change iscsi IP type from defines to enum.
  * Handle recv() returning 0 in iscsid_response()
* Fri Aug 20 2021 Lee Duncan <lduncan@suse.com>
- Merged latest upstream, which includes:
  * iscsid: set PR_SET_IO_FLUSHER (bsc#1188869)
* Wed Jul 21 2021 Lee Duncan <lduncan@suse.com>
- Merge latest upstream, which includeds:
  * Support the "qede" CMA-card driver. (bsc#1188579)
  * iscsistart: fix null pointer deref before exit
* Wed May 12 2021 Lee Duncan <lduncan@suse.com>
- Merge latest upstream, which added fix (bsc#1185930):
  * Set default 'startup' to 'onboot' for FW nodes
* Wed Apr 28 2021 Lee Duncan <lduncan@suse.com>
- Local (SUSE) change: update iscsi.service so that it tries to
  logon to any "onboot" and firmware targets, in case a target
  was offline when booted but back up when the service is started.
  (bsc#1153806)
* Wed Apr 28 2021 Lee Duncan <lduncan@suse.com>
- Merged with latest from upstream, which contains these fixes:
  * Add "no wait" option to iscsiadm firmware login
  * Check for ISCSI_ERR_ISCSID_NOTCONN in iscsistart
  * Log proper error message when AUTH failure occurs
* Thu Mar 11 2021 Lee Duncan <lduncan@suse.com>
- Updated to latest upstream 2.1.4 as 2.1.4-suse, which contains
  these changes not already present:
  * Enable iscsi.service asynchronous logins, cleanup services
    (bsc#1183421)
  * libopeniscsiusr: dont error loudly if a session isn't found when
    working through iscsi_sessions_get()
  * libopeniscsiusr: skip over removed sessions
  * libopeniscsiusr: fix error messages
  * Avoid hardcoding pkg-config to fix cross build
  * Fix iscsistart login issue when target is delayed.
* Tue Jan 26 2021 Lee Duncan <lduncan@suse.com>
- Update to latest upstream (no new tag yet). To fix
  bsc#1181313. Changes since last update added to
  open-iscsi-SUSE-latest.diff.bz2:
  * Fix iscsiadm segfault when exiting
  * iscsid: Add NO_SYSTEMD to CFLAGS
  * Change mkdir permissions to 0770, adjust usmask
  * Fix typo in util.py
  * iscsid: Do not allow conflicting pid-file options
  * iscsiadm: Fix memory leak in iscsiadm
  * libopeniscsiusr: Fix memory leak in iscsi_sessions_get()
  * libopeniscsiusr: Fix memory leak in iscsi_nodes_get()
  * idbm: Fix memory leak and NULL pointer dereference in idbm_rec_update_param()
  * Add etc/systemd/iscsi-init.service to SYSTEMDFILES Makefile variable
* Thu Dec 31 2020 Lee Duncan <lduncan@suse.com>
- Updated to upstream version 2.1.3 as 2.1.3-suse, for bsc#1179908
  (which addresses CVE-2020-17437, CVE-2020-17438, CVE-2020-13987,
  and CVE-2020-13988), changes include:
  * uip: check for TCP urgent pointer past end of frame
  * uip: check for u8 overflow when processing TCP options
  * uip: check for header length underflow during checksum calculation
  * fwparam_ppc: Fix memory leak in fwparam_ppc.c
  * iscsiuio: Remove unused macro IFNAMSIZ defined in iscsid_ipc.c
  * fwparam_ppc: Fix illegal memory access in fwparam_ppc.c
  * sysfs: Verify parameter of sysfs_device_get()
  * fwparam_ppc: Fix NULL pointer dereference in find_devtree()
  * open-iscsi: Clean user_param list when process exit
  * iscsi_net_util: Fix NULL pointer dereference in find_vlan_dev()
  * open-iscsi: Fix NULL pointer dereference in mgmt_ipc_read_req()
  * open-iscsi: Fix invalid pointer deference in find_initiator()
  * iscsiuio: Fix invalid parameter when call fstat()
  * iscsi-iname: Verify open() return value before calling read()
  * iscsi_sysfs: Fix NULL pointer deference in iscsi_sysfs_read_iface
* Mon Nov 30 2020 Lee Duncan <lduncan@suse.com>
- Updatged to latest upstream, including:
  * iscsiadm: Optimize the the verification of mode paramters
  * iscsid: Poll timeout value to 1 minute for iscsid
  * iscsiadm: fix host stats mode coredump
  * iscsid: fix logging level when starting and shutting down daemon
  * Updated iscsiadm man page.
  * Fix memory leak in sysfs_get_str
  * libopeniscsiusr: Compare with max int instead of max long
- Systemd unit files should not depend on network.target (bsc#1179440),
  updating:
  * open-iscsi-SUSE-latest.diff.bz2
* Wed Nov  4 2020 Lee Duncan <lduncan@suse.com>
- Updated to latest upstream, including async login ability:
  * TODO: Update to todo list.
  * Implement login "no_wait" for iscsiadm NODE mode
  * iscsiadm buffer overflow regression when discovering many targets at once
  * iscsid: Check Invalid Session id for stop connection
  * Add ability to attempt target logins asynchronously
* Tue Nov  3 2020 Franck Bui <fbui@suse.com>
- %%service_del_postun_without_restart is now available on SLE
  More accurately it's been introduced in SLE12-SP2+ and SLE15+
  +-------------------------------------------------------------------
* Sat Jul 25 2020 Lee Duncan <lduncan@suse.com>
- Upgrade to upstream vresion 2.1.2 as 2.1.2-suse (for
  jre#SES-1081), including:
  * use openssl for random data generation
  * Misspelled socket name might cause confusion to inexperienced user.
  * iscsi/libopeniscsiusr:add libopeniscsiuser_node.h to HEADERS
  * Let initiator name be created by iscsi-init.service.
  * iscsi: fix fd leak
  * iscsi: Add break to while loop
  * Fix compiler complaint about string copy in iscsiuio
  * Fix a compiler complaint about writing one byte
  * Fix issue with zero-length arrays at end of struct
  * Add iscsi-init.service
  * Proper disconnect of TCP connection
  * Fix dependency on new systemd RPM macro
  * Fix SIGPIPE loop in signal handler
  * Update iscsi-iname.c
  * log:modify iSCSI shared memory permissions for logs
  * Sequence systemd services correctly when upgrading
  * Ignore iface.example in iface match checks
  * More changes for musl.
  * Fix type mismatch under musl.
  * Change include of <sys/poll.h> to <poll.h>
  * Add Wants=remote-fs-pre.target for sequencing.
  * Add workaround in SPEC file for installcheck.
  * Fix issue where "iscsi-iname -p" core dumps.
  * iscsi-iname: fix iscsi-iname -p access NULL pointer without given IQN prefix
  * Fix iscsi.service so it handles restarts better
  Replacing open-iscsi-2.1.1-suse.tar.bz2 with open-iscsi-2.1.2-suse.tar.bz2,
  and updating open-iscsi-SUSE-latest.diff.bz2 to empty, since initially
  there are no differences.
* Mon Jun  8 2020 Lee Duncan <lduncan@suse.com>
- Merged in latest upstream. Summary:
  * Let initiator name be created by iscsi-init.service.
  * iscsi: fix fd leak
  * iscsi: Add break to while loop
  * Fix compiler complaint about string copy in iscsiuio
  * Fix a compiler complaint about writing one byte
  * Fix issue with zero-length arrays at end of struct
  * Add iscsi-init.service
  * Proper disconnect of TCP connection
  * Fix SIGPIPE loop in signal handler
  * Update iscsi-iname.c
  * log:modify iSCSI shared memory permissions for logs
  * Ignore iface.example in iface match checks
  * More changes for musl.
  * Fix type mismatch under musl.
  * Change include of <sys/poll.h> to <poll.h>
  * iscsi-iname: fix iscsi-iname -p access NULL pointer without given IQN prefix
  Note that the "Add iscsi-init.service" change adds a new systemd
  service called "iscsi-init", that creates the iSCSI initiator name
  file /etc/iscsi/initiatorname.iscsi, if and only if it does not
  exist. This obviates the need to do this from the SPEC file, now
  updated.
  Since this was not a version-number update, in addition to modifying
  the SPEC file, also updates:
  * open-iscsi-SUSE-latest.diff.bz2
* Sat May  2 2020 Lee Duncan <lduncan@suse.com>
- Update SPEC file to handle the fact that the
  service_del_postun_without_restart RPM macro exists
  in factory but not in SLE. No functional change
  for factory.
* Tue Apr  7 2020 Lee Duncan <lduncan@suse.com>
- Updated service_del_preun and service_del_postun for iscsi and
  iscsiuio packges in SPEC file, so that services get started/
  stopped in the correct order, and changed systemd macros so
  that iscsi login service iscsi.service is not restarted during
  package upgrade (bsc#1166650)
* Wed Apr  1 2020 Lee Duncan <lduncan@suse.com>
- Update with two upstream commits:
  * Fix issue where "iscsi-iname -p" core dumps. (found upstream)
  * Fix iscsi.service so it handles restarts better (bsc#1163499)
  * Add Wants=remote-fs-pre.target for sequencing. (bsc#1158536)
  updating:
  * open-iscsi-SUSE-latest.diff.bz2
* Thu Mar 26 2020 Lee Duncan <lduncan@suse.com>
- Update SPEC file to work around issue with installcheck
  SUSE script. Update the SPEC file while there.
* Tue Mar  3 2020 Lee Duncan <lduncan@suse.com>
- Merged in latest upstream (2.1.1), which is mainly a bug-fix
  release over 2.1.0, including changing the test suite from
  shell-based to python3-based, replacing
  open-iscsi.2.1.0-suse.tar.bz2 with open-iscsi-2.1.1-suse.tar.bz2
  and resetting open-iscsi-SUSE-latest-diff.bz2
* Fri Jan 31 2020 Lee Duncan <lduncan@suse.com>
- Bug fixes, including addig support for "-fno-common"
  compiler option, 586 bug fixes, a bug fix for SHA1
  handling, and other needed but small fixes (bsc#1160287),
  updating:
  * open-iscsi-SUSE-latest.diff.bz2
* Mon Nov 18 2019 Lee Duncan <lduncan@suse.com>
- Merged in latest upstream (2.1.0), including more fixes for
  iscsiuio, and cleanup/bug-fixes of new CHAP code.
  This replaces open-iscsi-2.0.878-suse.tar.bz2 with
  open-iscsi-2.1.0-suse.tar.bz2, and it resets
  open-iscsi-SUSE-latest.diff.bz2 with fixes after 2.1.0-suse.
  Also, updated the Summary lines in the spec file that
  started with "iSCSI ...", since rpmlint didn't like
  them starting with a non-capital letter, and updated the
  version number for iscsiuio to match the code.
* Sat Nov  9 2019 Lee Duncan <lduncan@suse.com>
- Use SPEC-file macro for systemd generator directory, since
  the libexec macro is changing from /usr/lib to /usr/libexec.
* Fri Nov  1 2019 Lee Duncan <lduncan@suse.com>
- Fix issue where CHAP was not working after latest update
  (bsc#1155510), updating:
  * open-iscsi-SUSE-latest.diff.bz2
* Fri Oct 18 2019 Lee Duncan <lduncan@suse.com>
- Merge in latest upstream, with fixes for:
  * Support CHAP SHA-1, SHA-256, SHA3-256 vis openssl libcrypto
  - this requires an update of the SPEC file, as well
  * Initialize timeout for printing specific session info
  Updating (in addition to the SPEC file):
  * open-iscsi-SUSE-latest.diff.bz2
* Fri Sep 13 2019 Lee Duncan <lduncan@suse.com>
- Upgraded to upstream version 2.0.878, which becomes 2.0.878-suse
  with our (few) SUSE-specific changes needed for our build system.
  Changes include:
  * general bug fixes in iscsid, iscsiadm, and libopeniscsiusr,
    including better lock handling for multiple instances of iscsiadm
  * iscsiuio/qedi updates
  * systemd service-file updates/cleanups
  This replaces open-iscsi-2.0.877-suse.tar.bz2 with
  open-iscsi-2.0.878-suse.tar.bz2, and it resets
  open-iscsi-SUSE-latest.diff.bz2 with fixes after 2.0.878.
* Mon Aug 12 2019 Martin Liška <mliska@suse.cz>
- Enable LTO on aarch64 as the gcc9 package issue is fixed:
  https://gcc.gnu.org/bugzilla/show_bug.cgi?id=91386
* Thu Aug  1 2019 Lee Duncan <lduncan@suse.com>
- Disable LTO (Link Time Optimization) on aarch64 since it seems
  to fail -- iscsiadm core dumps almost immediately (bsc#1143192),
  updating the SPEC file.
* Wed Jul 17 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Ensure /etc/iscsi/initiatorname.iscsi has reproducible size
  works around https://github.com/rpm-software-management/rpm/pull/229,
  updating the SPEC file
* Tue Jul  9 2019 Lee Duncan <lduncan@suse.com>
- Added latest upstream changes, including:
  * iscsiuio: update version to 0.7.8.6
  * iscsiuio: allow processing of iscsid requests in DHCP failure condition
  * rec update: disable the idbm_lock in read/write when updating the rec
  Updating:
  * open-iscsi-SUSE-latest.diff.bz2
* Wed Jun 12 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut the build queues by allowing usage of systemd-mini
* Tue Jun  4 2019 Lee Duncan <lduncan@suse.com>
- Added latest upstream changes, including:
  - iscsiuio: Stop using /var directory for PIDfile and locks
  - iscsiuio: improve daemon synchronization (bsc#1135070)
  - fix pipe notification code
  - add systemd support for iscsiuio
  - make iscsid systemd usage optional
  - fix possible discovery hang timeout
  - fix iscsiuio systemd disablement
  Updating:
  * open-iscsi-SUSE-latest.diff.bz2
* Tue Mar 26 2019 Lee Duncan <lduncan@suse.com>
- Added latest upstream changes, including:
  * Fix output of node printing for multiple paths.
  * Fix printing of node database again.
  * Add Restart=on-failure option to iscsid.service
  * Fix node print return value when no nodes.
  Updating:
  * open-iscsi-SUSE-latest.diff.bz2
* Wed Jan 23 2019 lduncan@suse.com
- Merged latest upstream commits to get needed fix:
  * Fix output for iscsiadm node/iface print level P1 (needed
    for bsc#1122938)
  * Updated iscsiadm man page: add "onboot" handling.
  Updating:
  * open-iscsi-SUSE-latest.diff.bz2
* Mon Jan 14 2019 lduncan@suse.com
- Update SPEC file to allow %%_libdir macro to override LIB_DIR
  when building or installing
* Mon Jan 14 2019 lduncan@suse.com
- Update SPEC file to use %%license macro for COPYING
  file so that it gets delivered when when other docs
  are excluded (bsc#1121877)
* Thu Dec  6 2018 lduncan@suse.com
- Fixed iscsiuio issues (bsc#1116712) by merging the latest from
  upstream, bringing the iscsiuio version to v0.7.8.5, updating:
  * open-iscsi-SUSE-latest.diff.bz2
* Tue Nov 13 2018 lduncan@suse.com
- Updated to latest upstream, with fixes:
  * Use pkg-config in Makefiles for newer libraries.
  * Merge pull request #145 from gonzoleeman/fix-i586-build-warnings
  * Fix i586 build issues with string length overflow.
  * iscsistart is not installed
  * iscsiuio: Do not flush tx queue on each uio interrupt.
  updating:
  * open-iscsi-SUSE-latest.diff.bz2
  Also, update the SPEC file: no more need to specify libkmod
  or libsystemd, since upstream handles that now.
* Wed Oct 24 2018 lduncan@suse.com
- Updated SPEC file with Obsoletes for library, and disclaimer
  abot updating SPEC file directly.
  Also, added using KBUILD_BUILD_TIMESTAMP to create reproducable
  man pages (bsc#1047218)
* Wed Oct 17 2018 lduncan@suse.com
- Upgraded to upstream open-iscsi version 2.0.877, which will be
  merged with our (few) changes and tagged 2.0.877-suse. See the
  Changelog file for a details list of changes in this upstream
  update. This update replaces:
  * open-iscsi-2.0.876-suse.tar.bz2 (old)
  with
  * open-iscsi-2.0.877-suse.tar.bz2 (new)
  and resets the file:
  * open-iscsi-SUSE-latest.diff.bz2
  to be our local changes since version 2.0.877-suse. The spec
  file is updated as well.
* Thu Sep 27 2018 lduncan@suse.com
- Merge the latest upstream code, updating the libopeniscsiusr
  version from 0_1_0 to 0_2_0, which updates the SPEC file. Also
  updated with new code:
  * open-iscsi-SUSE-latest.diff.bz2
* Tue Sep  4 2018 lduncan@suse.com
- Use libkmod instead of running modprobe (bsc#1106685), updating
  the spec file, and:
  * open-iscsi-SUSE-latest.diff.bz2
* Fri Aug 31 2018 lduncan@suse.com
- iscsiuio: limit retries on dhcpv6 (bsc#1106694 and bsc#1105916),
  updating:
  * open-iscsi-SUSE-latest.diff.bz2
* Thu May 31 2018 lduncan@suse.com
- Fix a core dump which can occur if iscsiuio is started then
  immediately stopped (bsc#1094797), updating:
  * open-iscsi-SUSE-latest.diff.bz2
* Mon Apr 23 2018 lduncan@suse.com
- Ensure we can get qedi transport name (bsc#1090275), updating:
  * open-iscsi-SUSE-latest.diff.bz2
* Wed Apr 18 2018 lduncan@suse.com
- Added upstream patch to allow host_id of 0 (bsc#1089687),
  updating:
  * open-iscsi-SUSE-latest.diff.bz2
* Fri Apr 13 2018 lduncan@suse.com
- Added 2 upstream commits to address issue of iscsi_if.h
  stayig in sync with kernel vesion (bsc#1086344), updating:
  * open-iscsi-SUSE-latest.diff.bz2
* Thu Mar 22 2018 lduncan@suse.com
- Cleaned up complaints by gcc-8 about strings (bsc#1084640)
- Fixed rpmlint complaint about libopeniscsiusr summary
  not starting with a capital letter
- Fixed libopeniscsiusr global variable overload
- No functional changes. This updates:
  * open-iscsi-SUSE-latest.diff.bz2, and
  * open-iscsi.spec
* Wed Feb 21 2018 lduncan@suse.com
- Ensure correct dependencies: main package must depend
  on (new) libopeniscsiusr package, and devel package
  must depend on main package (updating spec file)
* Tue Feb 20 2018 lduncan@suse.com
- Fix ARP booting issue with different subnets
  (bsc#1058463), updating:
  * open-iscsi-SUSE-latest.diff.bz2
* Wed Feb  7 2018 jengelh@inai.de
- Trim filler wording from description.
  Update old commands/RPM variables to macros.
- Implement shared library packaging guideline.
- Do not let fdupes run across partitions.
* Tue Jan 23 2018 lduncan@suse.com
- Removed the "rpm/" source directory from both the
  open-iscsi-2.0.876-suse.tar.bz2  and open-iscsi-SUSE-latest.diff.bz2
  files, since they are not needed for building and are not part
  of the upstream sources. They are still available under the
  git repository at github.com/hreinecke/open-iscsi.git. This means
  that changes to the spec file or the changes file will no longer
  require a change to the "*SUSE-latest*" file.
* Mon Jan 22 2018 lduncan@suse.com
- Update to latest upstream vesion 2.0.876, with very few
  SUSE-specific modifications, namely around things upstream
  does not care about, like SUSE-specific systemd files. Also,
  version number modified to add "-suse", as usual. See
  the Changelog file for more details on changes in this
  upstream version.
  This replaces open-iscsi-2.0.875-suse.tar.bz2 with
  open-iscsi-2.0.876-suse.tar.bz2, and resets
  open-iscsi-SUSE-latest.diff.bz2 to contain only changes
  since the 2.0.876-suse tag.
  These changes added a new libopeniscsiusr.so library, as
  well as include files under a new open-iscsi-dev package,
  if you want to link against this library.
  The SPEC file was also cleaned up using spec-cleaner.
* Thu Dec 14 2017 lduncan@suse.com
- Fix vulnerabilities found in iscsiuio by qualsys (bsc#1072312),
  updating: open-iscsi-SUSE-latest.diff.bz2
* Sat Dec  2 2017 lduncan@suse.com
- Added fixes for working with latest gcc (7.2.1),
  updating: open-iscsi-SUSE-latest.diff.bz2
* Wed Sep  6 2017 lduncan@suse.com
- Start iscsi logins before remote filesystems (bsc#1028323),
  updating:
  * open-iscsi-SUSE-latest.diff.bz2
* Sat Sep  2 2017 lduncan@suse.com
- Update to latest upstream 2.0.875, with a few SUSE-only
  modifications, replacing the 2.0.874-suse tarball with a
  2.0.875-suse version, and resetting the SUSE-latest-diff
  file to contain changes from 2.0.875-suse forward (bsc#1056689)
* Mon Aug 28 2017 lduncan@suse.com
- Add missing coreutils dependency for initrd macros (bsc#1055492)
  in SPEC file, which (as always) changes:
  * open-iscsi-SUSE-latest.diff.bz2
  +-------------------------------------------------------------------
* Thu Jul 27 2017 lduncan@suse.com
- Clear errno before calling strotull in iscsiadm
  (bsc#1029364). Note that this changes the file:
  * open-iscsi-SUSE-latest.diff.bz2
  which is changed each and every time this package is updated.
* Fri May 26 2017 lduncan@suse.com
- Added two iscsiuio upstream commits, for ipv6
  support, and general bug fixes (bsc#1040559)
* Fri Apr 28 2017 lduncan@suse.com
- Added support for qedi ping (bsc#1036238)
* Mon Apr 24 2017 lduncan@suse.com
- Fixed coredump when printing session information (bsc#1035236),
  backporting commit c8e6198dca71 from upstream open-iscsi
* Mon Apr 10 2017 lduncan@suse.com
- This is now the latest upstream open-iscsi, i.e. 2.0.874
  plus latest as of this date, together with SUSE-specific
  changes that are not yet upstream or not appropriate for
  upstream. (bsc#1032402/FATE#321911)
  Important changes in this update include:
  * qedi transport support
  * README cleanup
  * iscsiuio update
  * shutdown cleanup
  Also, the base tar file has been refactored to
  pre 2.0.874-suse as well as patches file for everything
  after that tag.
  Lastly, this update syncs this "Changes" file in Factory to and
  SLE, including SLE bug and FATE numbers, for reference.
* Fri Nov 25 2016 lduncan@suse.com
- Added two patches submitted upstream that
  make iscsi service shutdown cleaner (bsc#952437)
* Sat Oct 29 2016 lduncan@suse.com
- Added open-isns patch to remove Discovery
  Domain doubling when loading from file (bsc#897297),
  adding patch:
  * open-isns-Fix-DD-member-doubling-when-restoring-from-DB.patch
* Fri Oct 14 2016 lduncan@suse.com
- Stop manual sessions for iscsi service (bsc#989548)
* Fri May  6 2016 lduncan@suse.com
- Added patch submitted upstream that sets socket option
  to SO_LINGER (bsc#974102)
* Mon Apr 11 2016 lduncan@suse.com
- Update user-space open-iscsi tools (bsc#975217, FATE#320753),
  which included:
  + Backported changes from openSUSE:Factory branch:
  * Removing creation of open-isns RPM.
  * Allow setting host params to return EAGAIN errors.
  * Kernel include path
  * Fix iBFT target flags check.
  * fix typo
  * Fix typo in man page.
  * Use system-wide open-isns, not internal version.
  * iscsi: remove local copy of open-isns
  * iscsid: make sure actor is delated before rescheduling
  * iscsid/iscsiuio: remove uio poll
  * iscsid: fix iscsi_host_set_net_params return code
  * Syncing up utils/fwparam_ibft with upstream.
  * Syncing top-level files with upstream.
  * Fixed duplicate lines for subnet_mask and gateway
  + Update SPEC file for spliced open-isns by copying open-isns
  upstream tarball and patches from factory, since open-isns is no
  longer part of open-iscsi
* Thu Jan  7 2016 lduncan@suse.com
- Added 5 upstream patches for iscsiuio (bsc#960438):
  iscsiuio: Get the library to use based on uio sysfs name
  iscsiuio: Wait for iface to be ready before issuing the ping
  iscsiadm: let ping be tried after iface config is initialized
  iscsiuio: Add ping support through iscsiuio
  iscsid: Changes to support ping through iscsiuio
- Updated spec file copyright
- Build service git diffs now using 12-digit commit IDs
* Thu Oct  8 2015 lduncan@suse.com
- isns: exit with success when terminated with SIGTERM (bsc#948561)
* Thu Oct  8 2015 lduncan@suse.com
- isns: Adding signal managment around DB update,
  and ignore empty DB file (bsc#941791)
* Thu Oct  8 2015 lduncan@suse.com
- isns: Remove the debugging output from isnsd (bsc#949443)
* Mon Sep 28 2015 lduncan@suse.com
- added patch submitted upstream by QLogic:
  iscsiuio: Add QLogic Vendor ID to support newer NX2 HBAs
* Fri Sep  4 2015 lduncan@suse.com
- open-isns: For bsc#941944:
  - Allow setting server name with "--server"
  - Ensure we can reliably get our IP address
* Fri Sep  4 2015 lduncan@suse.com
- open-isns: For bsc#941791:
  - Set up /etc/isns/*.conf files when installing
  - Install /etc/isns/isnsadm.conf
* Thu Jul 30 2015 lduncan@suse.com
- Allow non-tcp transport for discovery daemon (bsc#939923)
* Thu Jul 23 2015 lduncan@suse.com
- Added iscsi_fw_login helper script, and new udev
  rule to call script when iBFT/iscsi boot targets
  added (bsc#869278)
* Mon Jun 29 2015 lduncan@suse.com
- Added rcsymlinks (bsc#932814)
- Cleaned up spec file for rpmlint
* Sun Jun 28 2015 lduncan@suse.com
- Updated open-iscsi to match upstream, as per bsc#936114,
  FATE#318770
  The following is a summary of changes. See
  git@github.com:hreinecke/open-iscsi.git for details of commits:
  a068906448ef Removing duplicate LDFLAGS from incorrect patch
  85ed2b4a1cb5 Prevent spinning over poll() when reconnecting to an inaccessible target
  bbffa1dd332d Fix incorrect list operation leading to out-of-order items on pend_list
  ce449cc8407f iscsiuio: Correct the handling of Multi Function mode
  e7f84d774c22 Reformat man page synopsis sections
  271b77dece32 Spelling and escaping error fixes.
  2022944815b2 Remove outdated Debian packaging code.
  d650915062d6 buildsys: respect CFLAGS and LDFLAGS from the outside
  97ae5d74d6bf buildsys: make 'make clean' idempotent
  770993b1e422 Fix small typo in iscsid.conf
  c9dcedb7b6a9 Remove duplicate newlines in log messages.
  2986f9c95f6f iscsid: don't re-read config file for every session logout
  d56f49d3f947 iscsid safe session logout
  3f59db921549 Add some more debug logging to actor.c
  75552f5519a8 iscsiuio CFLAGS fixes
  73e3e00c0e5e iscsid: fix order of setting uid/gid and drop supplementary groups
  99dfbeff1676 add discovery as a valid mode in iscsiadm.8
  688c2e9185f1 guard against NULL ptr during discovery from unexpected event
  c31ec6483815 Allow setting host params to return EAGAIN errors.
  973508df1daf fix regression in iscsi_tcp iface binding
  93c9d5ae1c86 Wake up to reap children
  24409900d9df Make running actors event-driven
  bc491ac31487 Remove actor_init and rename actor_new to actor_init
  cbcd086a2cf9 actor: Simplify actor_poll a little
  71ec348a2dfd actor: Unobfuscate ACTOR_MAX_LOOPS
  61d58fbf6de8 actor: Remove ACTOR_TICKS_10MS()
  f53eb0034618 actor: s/ACTOR_TICKS/actor_jiffies/
  dfe52b2423ff actor: simplify actor_check
  8667dcd5d628 actor: Mark actor_check static
  8037a0a30b8f Represent DHCP "origin" as an enum, not a string.
  da567155cfe9 Code cleanup: no functional changes
  6478eaac7b53 iscsiuio: Check return value from nic_queue_tx_packet
  1d07286fda46 iscsiuio: Remove set but unused variables
  382655137020 iscsiuio: Change nic_disable to return void
  7c233130687a iscsiuio: Use attribute(unused) for *icmpv6_hdr
  8e1d38215344 iscsiuio: Use attribute(unused) for variables that are unused but needed
  6ae604304b10 iscsiuio: Fix aliasing issue with IPV6_IS_ADDR_UNSPECIFIED
  63b450de0c29 iscsiuio: Resolve strict aliasing issue in iscsiuio/src/unix/nic.c
  c1e83d439f90 iscsiuio: Fix strict-aliasing warning with struct mac_address
  980c471e9f4e iscsiuio: Fix warning about non-matching types
  cb84219a4992 Fix missing header
  9d744ac8c039 Fix bad sizeof in memset
  67ff3a01e3ed Fix warning about possibly-uninitialized variable
  e5518c7a8f43 Fix build warnings for unused variables
  5d68768908e0 iscsid: don't round up when modifying padding len
  d21766d95e10 isns: Add docs for deregistering discovery domains.
  ed04ac2f9f32 iscsiadm : make iface.ipaddress optional in iface configs for transports that don't have a hard requirement on it.
  148854ae2d6e iscsiuio: Rebranding iscsiuio
  a3c40ba2ba4f iscsiadm: Initialize param_count in set_host_chap_info
  bfa2f55b0928 iscsid: Fix double close of mgmt ipc fd
  a037f5eaa9e0 iscsid: retry login for ISCSI_ERR_HOST_NOT_FOUND
  f0f3bbd25762 Fix StatSN in Open-iSCSI Stack.
  a9f4d169a95a be2iscsi: Fix MaxXmitDataLenght of the driver.
  cf1346a86489 iscsiuio: fix compilation
* Wed Apr 22 2015 lduncan@suse.com
- Double the size of the iscsiuio ARP tables,
  making it faster when switches present (bsc#922311)
* Wed Apr 22 2015 lduncan@suse.com
- Fixing ibft boot, completing commit 26020764daf70,
  which only fixed NIC context. Now boot context
  also fixed (bsc#902183)
* Mon Mar  9 2015 lduncan@suse.com
- Ported upstream commit 51c0b6ef8bc90:
  Supply strings for newly-added error numbers
* Mon Mar  9 2015 lduncan@suse.com
- Do not convert all "again" errors from transport to
  internal errors (bsc#903729)
- Update spec-file copyright date
* Fri Mar  6 2015 lduncan@suse.com
- Fixed iscsi.service start to ignore iscsiadm
  return value so that systemd knows service is
  running and can still shut it down (bsc#897565)
* Tue Nov 25 2014 lduncan@suse.com
- Fix isns server to allow legal registration sequence,
  including portal group (bsc#905670)
* Tue Oct 28 2014 lduncan@suse.com
- Added fix from Hannes to properly boot all iSCSI CNAs,
  fixing previous change (bnc#902183)
* Tue Sep 23 2014 lduncan@suse.com
- Added fix from hannes to fixup IPv6 iBFT interface
  description
* Mon Jul 28 2014 lduncan@suse.com
- Added iscsiuio spec file service macros (bnc#887143)
* Tue Jul  8 2014 hare@suse.de
- Remove unused variable 'path'
- Parse 'origin' value from iBFT
- iscsi_offload: fix detection of bnx2i (bnc#886198)
* Fri Jun  6 2014 hare@suse.de
- Valgrind fixes for iscsiuio (bnc#881692)
* Wed Jun  4 2014 lduncan@suse.com
- Added firewall service file for isns server (bnc#880305),
  adding file: open-iscsi-firewall.service
* Fri May 30 2014 hare@suse.de
- Install ibft-rule-generator (bnc#880336)
* Wed May 28 2014 hare@suse.de
- iscsi.service: do not logout from all sessions during shutdown
  (bnc#880338)
- iscsid.service: Fixup dependencies (bnc#880338)
* Fri May  2 2014 +0200 - hare@suse.de
- iscsi_offload: do not print error messages for be2iscsi
  be2iscsi HBAs display the firmware settings in
  /sys/firmware/iscsi_boot1 and only provide a subset
  of the iBFT settings (bnc#876137)
* Tue Mar 25 2014 lduncan@suse.com
- Added two not-yet-upstream patches for iscsiuio/systemd activation
  from Chris Leech (bnc#869567):
    iscsiuio-systemd-socket-activation-support.patch
    iscsiuio-systemd-unit-files.patch
  Updated spec file to handle install/package of new files.
* Fri Mar 21 2014 lduncan@suse.com
- Added an upstream patch from Mike Christie (bnc#869356):
  iscsi-tools-set-non-negotiated-params-early
* Fri Mar 14 2014 <michaelc@cs.wisc.edu>
  iscsid: Fix handling of iscsi async events.
    When iscsi targets send 32 or more iscsi async event pdus the
    initiator will run out of memory for events and this message:
    BUG: iscsid: Can not allocate memory for receive context.
    will be logged non stop. iscsid will then not be able to
    complate any more requests because it is stuck in a endless loop
    printing that message.
    This fixes the problem by having iscsid handle an event after it
    has read it in from netlink or the mgmt ipc. Previously we would
    queue all events then handle them.
* Tue Mar 11 2014 lduncan@suse.com
- Added two patches from QLogic, accepted up stream (bnc#866866):
  iscsiadm-fix-the-hostno-check-for-stats-submode-of-host-mode
  iscsiadm-fix-the-compile-time-warning
* Thu Feb 27 2014 lduncan@suse.com
- Updated systemd unit files (bnc#847953)
- Split iscsiuio out as separate package
  (part of bnc#858972)
* Thu Jan 30 2014 hare@suse.de
- Systemd integration for open-isns (FATE#316901)
* Wed Jan 29 2014 hare@suse.de
- Pulled in patches from upstream git (FATE#315963)
  * Replaced iscsiuio with upstream version
  * Switched to autotools when building iscsiuio
- Recreate SUSE-specific patches
  * Removed obsolete iscsiuio integration
  * Removed obsolete patches
  * Rediffed SUSE-specific patches
  * Removed patches
  - open-iscsi-openSUSE-12.3-first-merge.diff.bz2
  - open-iscsi-openSUSE-Factory-first-merge.diff.bz2
  - open-iscsi-openSUSE-Factory-qla4xxx-patches.diff.bz2
  - open-iscsi-sles11-sp2-latest.diff.bz2
  - open-iscsi-sles11-sp2-update.diff.bz2
  - open-iscsi-sles11-sp3-flash-update.diff.bz2
  - open-iscsi-sles11-sp3-general-updates-1.diff.bz2
  - open-iscsi-sles11-sp3-iscsiuio-update.diff.bz2
  * Added patches
  - open-iscsi-git-update.diff.bz2
  - open-iscsi-sles12-update.diff.bz2
- Build separate open-isns package (FATE#316901)
- Remove 'linux-iscsi' provides; package has last
  been used on SLES9.
* Thu Jan  9 2014 lduncan@suse.com
- Added open-iscsi-openSUSE-Factory-qla4xxx-patches.diff.bz2, with
  the following changes from QLogic (bnc#855859):
  iscsiadm.8: Updated man page for host statistics.
  README: Updated for host statistics.
  iscsi_tool: Add offload host statistics support.
  iscsiadm: Added document for description of iface attributes
  iscsi tools: Show iface params based on iface type
  iscsi tools: Let default type of iface be ipv4
  iscsi tools: iface params should be updated for node_rec as well.
  iscsi tools: Additional parameters for network settings
  iscsi tools: Ignore network parameter if not enabled/disabled
  iscsi tools: Use single function to set integer network parameters
  iscsi tools: Use single function to enable/disable network parameters
  iscsi tools: Use macro to set IPv4/IPv6 IP addresses
  iscsi_if.h: Additional parameters for network param settings
  iscsi_if.h: Remove numbers used for network parameter settings
  iscsi tools: Setup iface conf file with all iface attrs exported in sysfs
  README changes for adding support to set CHAP entry
  iscsi tools: Correctly get username_in and password_in flashnode params
  iscsiadm: Add support to set CHAP entry using host chap mode
  README changes to use long option --index instead of --flashnode_idx
  iscsiadm: Man page changes to use -x option for chap_tbl_idx
  iscsiadm: Use '-x' option instead of '-v' to specify chap_tbl_idx
  flashnode: Add support to set ISCSI_FLASHNODE_CHAP_OUT_IDX param
  iscsi tools: Print additional session info for flashnode session
  iscsiadm: Correctly check for invalid hostno and flashnode index
* Thu Dec 12 2013 lduncan@suse.com
- Fixed mkinitrd setup to not scan /etc/fstab
  (bnc#826700), changing:
  open-iscsi-openSUSE-Factory-first-merge.diff.bz2
* Mon Dec  2 2013 lduncan@suse.com
- Dropped this patch from OBS; moved to github repostiory:
  open-iscsi-2.0-873.patch
  The following patches updated to use new linux git
  requirements for longer hash values in patches, but not
  functionally changed:
  open-iscsi-openSUSE-12.3-first-merge.diff.bz2
  open-iscsi-sles11-sp2-latest.diff.bz2
  open-iscsi-sles11-sp2-update.diff.bz2
  open-iscsi-sles11-sp3-flash-update.diff.bz2
  open-iscsi-sles11-sp3-general-updates-1.diff.bz2
  open-iscsi-sles11-sp3-iscsiuio-update.diff.bz2
  This patch was also changed to absorb changes from
  open-iscsi-2.0-873.patch:
  open-iscsi-openSUSE-Factory-first-merge.diff.bz2
* Thu Nov 14 2013 crrodriguez@opensuse.org
- install the iscsistart utility which is required by dracut
* Fri Oct  4 2013 ohering@suse.de
- Remove usage of iscsiuio from mkinitrd scripts
- Add programs tags to mkinitrd scripts
  open-iscsi-2.0-873.patch
* Fri Sep 27 2013 lduncan@suse.com
- add support for systemd integration (bnc#827654)
  open-iscsi-openSUSE-Factory-first-merge.diff.bz2
* Wed Jul  3 2013 meissner@suse.com
- moved the open-iscsi branch to the SLES 11 SP3 codebase.
  Update coalesces and drops patches:
  iscsi-gen-initiatorname.sh
  open-iscsi-2.0-870-rc1-static.patch
  open-iscsi-2.0-870-rc1.tar.bz2
  open-iscsi-add-error-msg-to-log.c
  open-iscsi-add-mkinitrd-scriptlets
  open-iscsi-add-rhel5-compat
  open-iscsi-add-sles10-compat
  open-iscsi-allow-onboot-for-loginall
  open-iscsi-beta5-kernel-patch-update
  open-iscsi.changes
  open-iscsi-cxgb3i-support
  open-iscsi-error-check-in-db-lock-creation
  open-iscsi-fix-sysfs-get-value-null.patch
  open-iscsi-fixup-onboot-for-loginall
  open-iscsi-fw-crash-on-ppc
  open-iscsi-fwparam_ppc-string-overflow
  open-iscsi-header.patch
  open-iscsi-initiator-compile-warning
  open-iscsi-install-mkinitrd-scriptlets
  open-iscsi-iscsid-adjust-settings
  open-iscsi-iscsi_discovery-doc-fixes
  open-iscsi-load-ibft-before-reading-sys-firmware
  open-iscsi-login-retry-update
  open-iscsi-no-pid-file
  open-iscsi-option-no-pid-file
  open-iscsi-remove-dump-char
  open-iscsi-remove-trailing-tilde
  open-iscsi-rm-unused-variable
  open-iscsi-set-LOCK_DIR-during-compilation
  open-iscsi.spec
  open-iscsi-start-target-before-initiator
  open-iscsi-support-non-root-boot-volume.patch
  open-iscsi-suse-build-fixes
  open-iscsi-sync-modules-with-2.6.27
  open-iscsi-update-init-script
  open-iscsi-update-suse-init-scripts
- New patches:
  open-iscsi-openSUSE-12.3-first-merge.diff.bz2
  open-iscsi-sles11-sp2-latest.diff.bz2
  open-iscsi-sles11-sp2-update.diff.bz2
  open-iscsi-sles11-sp3-flash-update.diff.bz2
  open-iscsi-sles11-sp3-general-updates-1.diff.bz2
  open-iscsi-sles11-sp3-iscsiuio-update.diff.bz2
* Wed Jun  5 2013 lduncan@suse.com
- check return from nice() correctly (bnc#807936)
* Tue Jun  4 2013 lduncan@suse.com
- Branched from SLES 11 SP3
- Modified for openSUSE by removing iscsiuio references, and
  by changing service name from open-iscsi to iscsid (bnc#821695)
* Fri May 24 2013 lduncan@suse.com
- Adds support to be able to use isns discovery and
  bind the portals found to offload ifaces (bnc#820881)
* Sat May 18 2013 lduncan@suse.com
- Now handles boot-time non-root iSCSI volumes (bnc#630434)
* Thu May  9 2013 lduncan@suse.com
- Fixed iscsiadm name/value command-line parsing
  bug caused by previous update (bnc#818517)
* Fri Apr  5 2013 lduncan@suse.com
- Added iscsiadm support for user management of target adapter
  flash (bnc#810208)
* Thu Mar 14 2013 lduncan@suse.com
- Add open-iscsi-support-non-root-boot-volume.patch: handle non-
  root boot-time iscsi volumes (bnc#630434)
- Add open-iscsi-fix-sysfs-get-value-null.patch: accept "(null)"
  password as meaning no password, when using sysfs (bnc#766300)
* Mon Mar 11 2013 lduncan@suse.com
- Updated iscsiuio to latest (bnc#769125)
* Fri Sep  7 2012 lduncan@suse.com
- Added iscsiuio patches and other cleanup (bnc#751056)
* Thu Jun 21 2012 lduncan@suse.com
- Updated open-iscsi to version 2.0.873 (bnc#751056)
- Updated iscsiuio to version 0.7.4.3, to match
* Mon Feb  6 2012 hare@suse.de
- Do not install initiatorname.iscsi (bnc#742430)
- iscsi_offload: Fixup qla4xxx booting (bnc#742570)
* Fri Feb  3 2012 hare@suse.de
- Append '.suse' to version string (bnc#713975)
- iscsiadm dumps core on invalid config file (bnc#742570)
- Load iscsi_tcp kernel modules unconditionally (bnc#738040)
* Fri Dec  9 2011 hare@suse.de
- iscsiadm: Return correct error when login fails (bnc#715071)
- Add bnx2i to list of modules (bnc#718014)
- iscsi_offload: Configure interface from iBFT
- Allow modifications for iface.gateway and iface.subnet_mask
- Remove OFFLOAD_BOOT_SUPPORTED define
- iscsiadm: Allow -d flag for firmware mode
- iscsid prints invalid log message
- Start iscsiuio early in boot.open-iscsi (bnc#731216)
* Mon Nov 28 2011 hare@suse.de
- Enable offload interfaces from iscsi_offload script (bnc#730157)
* Fri Nov 25 2011 hare@suse.de
- Start iscsiuio manually again (bnc#732798)
- Remove compat code from iscsiuio
- Fixup build warnings
- Add uip_broadcast() header declaration
- Handle error when starting iscsiuio from iscsid
- Fixup definition for krecv_conn_state()
- Include iscsi-gen-initiatorname script
- Update mkinitrd scripts for iSCSI offload boot (bnc#732634)
- Added launching of iscsiuio before session sync (bnc#731216)
* Fri Nov  4 2011 hare@suse.de
- Update iscsiuio to 0.7.0.14g (bnc#726708)
- Merge with mainline:
  * Update for mixed mode on qla4xxx (bnc#727415)
  * Fix printing of unknown host values in iscsiadm
  * Fix IPv6 ibft/firmware boot
  * Remove iSNS RFC files
- Stop iscsiuio when run inside initrd (bnc#728095)
* Thu Oct 27 2011 aj@suse.de
- Rename init scripts (bnc#661401).
* Mon Oct 24 2011 hare@suse.de
- Update iscsiuio to 0.7.0.14f (bnc#687392)
- Default iscsid version to 872 for iscsiuio (bnc#687392)
* Mon Oct 10 2011 hare@suse.de
- Update iscsi_offload script (bnc#718014)
- Fixup mac address calculation
- Fixup iscsi_offload script to work on qla4xxx (bnc#722268)
* Fri Oct  7 2011 hare@suse.de
- Fix build error.
* Thu Oct  6 2011 hare@suse.de
- Merge with mainline:
  * Include qla4xxx support (bnc#722268)
  * Multiple sessions from single iface (bnc#713975)
- Fix memory leak when parsing config file
* Mon Sep 19 2011 hare@suse.de
- Update iscsiuio to 0.7.0.14d (bnc#687392)
- Fixup README (bnc#711953)
- Start iscsiuio from iscsid (bnc#718014)
* Fri Sep 16 2011 hare@suse.de
- Update iscsiuio to 0.7.0.14 (bnc#687392)
* Fri Jul 29 2011 hare@suse.de
- iscsi fails to start with bnx2i offloading (bnc#708261)
- /etc/init.d/open-iscsi fails to shutdown daemon on 'stop'
- Add 'iscsi_offload' script (FATE#311488)
- Configure all interfaces from iBFT (FATE#311345)
* Mon Jul 18 2011 hare@suse.de
- Update iscsi_uio to version 0.7.0.8 (bnc#687392)
- Add uip callbacks (bnc#687392)
- Fixup spec file to refer to iscsiuio
* Tue Jun 21 2011 hare@suse.de
- Update to version 2.0-872 (FATE#312030)
- Update brcm_iscsi_uio to version 0.7.0.4 (FATE#312028)
- Rediff patches to apply to upstream codebase
- Include scripts for automated build
* Mon Jun  6 2011 aj@suse.de
- Fix build with newer glibc.
* Wed Feb  2 2011 mweckbecker@suse.de
- Fix the following issues:
  bnc#608224: iscsi stop fails though root is not on iSCSI device-
    FIXUP
  bnc#435689: root on multipath iSCSI SLES10 SP2 host occasionally
    hangs
  bnc#455995: iSCSI connections should not get closed if unmount
    fails
* Mon Jan 31 2011 mweckbecker@suse.de
- open-iscsi-start-multipath-before-iscsi: updated to apply w/
  fuzz=0
* Fri Jul 30 2010 hare@suse.de
- Parse iface entry correctly in init script
- Tear down block device stack on 'open-iscsi stop' (bnc#608224)
* Mon Jun 28 2010 hare@suse.de
- open-iscsi stop returns 'failed' for root on iSCSI (bnc#608224)
- Extract correct session information for firmware sessions
  (bnc#617883)
- Start multipathd before open-iscsi (bnc#603382)
* Mon Apr 26 2010 ro@suse.de
- also enter boot.multipath in Should-Stop
* Mon Apr 26 2010 hare@suse.de
- Start boot.multipath prior to boot.open-iscsi (bnc#595629)
* Tue Apr 20 2010 hare@suse.de
- Do send SIGTERM to pid 0 (bnc#589064)
* Thu Apr 15 2010 hare@suse.de
- Set correct 'interface' variable for mkinitrd (bnc#596627)
* Tue Apr 13 2010 hare@suse.de
- Remove ibft mkinitrd scripts.
* Mon Apr 12 2010 hare@suse.de
- Only set nettype to 'dhcp' if a valid DHCP address was found
  (bnc#576601)
- Do not print 'umounting failed' on shutdown (bnc#581259)
* Fri Mar 26 2010 hare@suse.de
- Do no umount root fs on shutdown (bnc#581259)
* Thu Mar 25 2010 hare@suse.de
- Update brcm_uio daemon to version 0.5.7 (bnc#576601)
- Load transport modules if configured (bnc#590531)
* Fri Mar 12 2010 mmarek@suse.cz
- Do not hardcode the iscsi_ibft module in the iscsi mkinitrd
  script, the ibft script handles this correctly (bnc#528657).
* Fri Mar 12 2010 hare@suse.de
- Don't close sessions if umount fails (bnc#581259)
* Mon Feb 22 2010 hare@suse.de
- Start brcm_uio daemon conditionally if HW is present (bnc#576601)
* Mon Feb 15 2010 mmarek@suse.de
- Include <sys/types.h> for pid_t.
* Mon Feb  8 2010 hare@suse.de
- Add brcm_uio daemon for bnx2i iSCSI offload (bnc#576601)
* Thu Dec 17 2009 hare@suse.de
- Do not modify network parameter when iBFT is not found
  (bnc#562030)
- Use correct value for iBFT 'origin' parameter (bnc#565116)
* Thu Dec 10 2009 hare@suse.de
- iscsiadm fails to read ibft (bnc#561596)
* Wed Nov 18 2009 hare@suse.de
- Update to 2.0-871 (FATE#307216)
- Renumber patches
- Add mkinitrd scriptlet for iBFT setup (bnc#541892)
- Fall back to kernel name in mkinitrd setup if udev fails
- Allow empty usernames for CHAP
- Read initiatorname correctly from sysfs (bnc#541882)
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Wed Aug 19 2009 hare@suse.de
- Synchronize startup settings (bnc#514273)
- Fix daemon segfault with CHAP (bnc#519402)
- Do not use temp file in iscsi_discovery (bnc#528711)
* Sun Jun 21 2009 crrodriguez@suse.de
- build with fno-strict-aliasing
- do not use static libc, this does not work in reality, use
  of getaddrinfo(3) requires shared libraries at runtime
* Tue Feb 10 2009 hare@suse.de
- search_ibft() might crash when no iBFT is found (bnc#471475)
* Mon Jan 26 2009 ro@suse.de
- change fillup call from "-Y" to "-y" the boot script has
  been present in this package for long enough (SLES10-GA)
* Thu Jan 22 2009 hare@suse.de
- Fix relogin retry handling (bnc#466846)
* Mon Dec  8 2008 hare@suse.de
- Remove trailing tilde from /etc/iscsi/ifaces.example (bnc#450870)
* Fri Dec  5 2008 hare@suse.de
- Fixup 'onboot' for loginall (bnc#449108)
- Remove unused 'dump_char' definition in log.c
- Load ibft module before reading /sys/firmware (bnc#450897)
* Tue Dec  2 2008 hare@suse.de
- iscsiadm -m fw crashes on ppc (bnc#449116)
* Thu Nov 20 2008 hare@suse.de
- Add cxgb3i support (bnc#433500, FATE#304154)
- No pid file from init scripts
* Thu Nov 13 2008 hare@suse.de
- Update iscsi-gen-initiatorname to work with newer kernels
  (bnc#443509)
* Wed Nov 12 2008 hare@suse.de
- Update SUSE init scripts to work with newer kernels
- Move mkinitrd scriptlets to git repository
- Fixes for root-on-iSCSI:
  * Update mkinitrd scripts to work with newer kernels (bnc#435215)
  * Allow 'onboot' for iscsiadm -L
  * Add option to not write a pid file
- Update login retry mechanism to work around the spanning-tree
  issue (bnc#433363)
* Wed Sep  3 2008 hare@suse.de
- Pull in fixes from upstream git repository
- Call mkinitrd_setup during %%post and %%postun (bnc#413709)
* Thu Aug 28 2008 cthiel@suse.de
- fix init script
* Thu Jul 24 2008 hare@suse.de
- Update to 2.0-870-rc1
  * Fix login redirection
  * Fix NOP timeout handling
  * Various small bugfixes
- Include mkinitrd scriptlets.
* Tue Apr 29 2008 hare@suse.de
- Pull in fixes from upstream git repository
* Mon Apr 21 2008 hare@suse.de
- Scan memory area for iBFT correctly (bnc#378837)
* Tue Apr 15 2008 hare@suse.de
- Synchronize with SLES10 SP2
* Thu Apr 10 2008 hare@suse.de
- Tear down device stack before logging out (bnc#378141)
* Fri Apr  4 2008 hare@suse.de
- Don't try to print invalid log messages (bnc#372719)
- Cleanup IPC identifiers upon error (bnc#372719)
- Print iBFT error messages to stderr (bnc#372725)
* Mon Mar 17 2008 hare@suse.de
- Don't fail init script if called twice with 'stop' (bnc#369300)
* Wed Mar 12 2008 hare@suse.de
- Add parameter '-i' to fwparam_ibft for mkinitrd (bnc#277106)
- Only logout from targets marked as 'automatic' (bnc#369767)
* Mon Mar 10 2008 hare@suse.de
- Synchronize with git repository
- Fixes to simplify build process
- Re-implement fwparam_ibft (bnc#367437)
* Wed Mar  5 2008 hare@suse.de
- Fixup '-op' to not overwrite other nodes on discovery
  (bnc#365259)
* Mon Feb 18 2008 hare@suse.de
- Fixup /etc/init.d/boot.open-iscsi to use correct syntax
  for iscsiadm (bnc#360674)
* Thu Feb  7 2008 hare@suse.de
- Add '-op' option to discovery to avoid overwriting
  of existing nodes (bnc#357197)
* Thu Dec  6 2007 hare@suse.de
- Update to official version 2.0-866
- Include latest git patches (FATE#303021)
- Start initiator after iSCSI target (FATE#302415)
* Fri Nov 30 2007 hare@suse.de
- Rediscover all targets to make sure the network
  is up (#307930, #251675)
- Fixup debug option to iscsiadm (#346504)
* Thu Nov 15 2007 hare@suse.de
- Do not overwrite existing node records when doing a
  discovery (#278172)
* Fri Oct 26 2007 bphilips@suse.de
- Scan BIOS memory in blocks to avoid crash on buggy
  BIOS (#293845)
- Don't unload modules on stop to avoid kernel oops (#328923)
* Thu Aug  2 2007 hare@suse.de
- Fix insecure privileges and credential verification (#280413)
* Mon Jul  9 2007 hare@suse.de
- update to svn r866
- include latest git patches
* Fri May 11 2007 hare@suse.de
- Correct target and initiator mixup for ppc (#273600)
- Print LUN correctly (#271292)
* Thu Apr 26 2007 hare@suse.de
- fwparam_ibft crashes with Broadcom chips (#267458)
* Wed Apr  4 2007 hare@suse.de
- update to official release 2.0-754
- update to svn r779
- Include changes from SLES10 SP1
* Fri Mar 30 2007 hare@suse.de
- Include fwparam_ibft program for OpenPROM (#226682)
* Wed Mar 28 2007 hare@suse.de
- Return status '6' when root on iSCSI is not enabled (#257979)
* Fri Mar 16 2007 hare@suse.de
- Fix typo in output of fwparam_ibft (#250445)
* Thu Mar  8 2007 hare@suse.de
- connect() to the daemon might fail on busy machines (#244649)
* Mon Mar  5 2007 hare@suse.de
- Add /usr/bin/iscsi-dbconvert to convert SLES10 GA
  databases to new format (#251298)
* Fri Feb 16 2007 hare@suse.de
- Fix iscsiadm to print session info correctly (#243203)
* Thu Feb  8 2007 hare@suse.de
- update to svn r768
  - Update iSNS support (#243203)
- Correct typo in /etc/init.d/boot.open-iscsi (#243203)
* Fri Feb  2 2007 hare@suse.de
- Umount all luns on shutdown (#223484)
* Wed Jan 31 2007 hare@suse.de
- Remove the start iSCSI after Xen hack (#231077)
- Fixup /etc/init.d/boot.open-iscsi script (#239819)
* Thu Jan 18 2007 hare@suse.de
- Fix compat mode to display the record id.
- Add /sbin/iscsi-gen-initiatorname to generate
  a default iSCSI initiatorname.
* Mon Jan 15 2007 hare@suse.de
-  Fixup %%post scripts.
* Mon Jan 15 2007 hare@suse.de
- Reference symlink to /etc/iscsid.conf in rpm.
* Fri Jan 12 2007 hare@suse.de
- update to official version 2.0-707
- update to svn r759
  - Include iBFT BIOS tool (FATE 301671)
- Implement compability mode for iscsiadm
* Fri Oct 20 2006 hare@suse.de
- Update to svn r713
- Use /dev/urandom instead of rand() (#180837)
- Fixup init script
* Fri Oct  6 2006 hare@suse.de
- Update to official version 2.0-707
* Fri Jul 28 2006 olh@suse.de
- remove unused boot.proc from boot.open-iscsi (#181972)
* Mon Jun 19 2006 hare@suse.de
- update to svn r606
  - Include local patches
  - Fix OCFS2 hangs (#185107, #180773)
* Thu Jun  1 2006 hare@suse.de
- Added new startmode 'onboot' for root on iSCSI
- Added new init script boot.open-iscsi startup
  iscsid as early as possible (#176804)
* Wed May 31 2006 hare@suse.de
- update to svn r595
  - Include local patches
  - Fix lockup on target restart for real (#176151)
* Mon May 22 2006 hare@suse.de
- update to svn r581
  - Fix lockup when target is restarted (#176151)
- Start open-iscsi after Xen (#177381)
* Fri May 19 2006 hare@suse.de
- update to svn r574
  - Fix machine hang during error recovery (#174166)
- Display chap secrets for yast (#149055)
* Tue May  2 2006 hare@suse.de
- update to svn r564
  (contains all local changes)
* Tue Apr 25 2006 wrwhitehead@novell.com
- Fix communication hang (#157463).
- The iscsi-tcp_data_ready callback needs to empty out the
  tcp receive queue rather than just rely on the callback to
  occur for every message in the receive queue.
* Fri Apr 21 2006 hare@suse.de
- update to svn r545
  Fixes a crash with Wasabi targets (#157463).
* Wed Mar 22 2006 hare@suse.de
- Add rcopen-iscsi link (#158230)
- Check for active records before deletion (#149935)
- Do not display error messages on startup if no
  records are found.
* Fri Mar 10 2006 hare@suse.de
- Update to svn r520 (contains all local changes)
- Add documentation for discovery types (#149936)
* Tue Feb 28 2006 hare@suse.de
- Fixed type of portal_group_tag (#153638)
* Tue Feb 21 2006 hare@suse.de
- Fixed open-iscsi startup script (#148982)
* Mon Feb 20 2006 hare@suse.de
- Update to svn r495
- Implement iSCSI boot support (FATE #140350)
* Thu Feb  9 2006 hare@suse.de
- Update to svn r488 to match kernel revision
  (#149412).
- Remove obsolete patches.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 hare@suse.de
- Update to svn r473
- Enhance start script
- Fix appearent login failures.
* Fri Jan 20 2006 hare@suse.de
- Update to svn r471
- Fix start script.
* Mon Jan 16 2006 hare@suse.de
- Add Provides/Obsoletes tag.
* Fri Jan 13 2006 hare@suse.de
- Rebasing package to open-iscsi-0.5-454
- Update to svn r457
* Mon Dec 19 2005 hare@suse.de
- Update to svn r446.
* Thu Nov  3 2005 hare@suse.de
- Update to svn r436.
* Thu Sep  8 2005 hare@suse.de
- Update to svn r408.
  (Added NOOP IN handling)
- Removed obsolete patches
* Mon Aug 22 2005 hare@suse.de
- Update to svn r401.
- Fixed package to install properly.
- Fixed init script
- Added iscsi-iname to generate iSCSI Initiatorname.
* Mon Aug  8 2005 hare@suse.de
- Update to svn r389.
* Thu Jul  7 2005 hare@suse.de
- Initial version 0.3rc6-369
